# David Nichols
# This work is licensed under a Creative Commons Attribution 4.0 International License.
# http://creativecommons.org/licenses/by/4.0/

# Supplementary material for "A scientometric analysis of 15 years of CHINZ conferences"
# http://dx.doi.org/10.1145/2808047.2808060


R.version
setwd("C:/Users/daven/Google Drive/research/CHINZ-bibliometrics/analysis")
getwd()

######################################################
# libraries

library(ggplot2)
library(grid)
library(stringr)


# set up directories
data.dir <- getwd()
results.dir <- file.path(paste(getwd(), "results", sep = ""))

data.csv.filename <- "chinz-data.csv"
data.path <- file.path(data.dir, data.csv.filename, fsep = .Platform$file.sep)
chinzData <- read.csv(data.path, header = TRUE)
chinzData.df <- as.data.frame(chinzData)

###############################################

# Data Cleaning

#remove any comments

chinzData.df$comments <- NULL

#affiliation harmonisation

chinzData.df[chinzData.df == "University of Technology Sydney"] <- "University of Technology, Sydney"
chinzData.df[chinzData.df == "stellaris dance nz"] <- "stellaris dance NZ"
chinzData.df[chinzData.df == "UNITEC"] <- "Unitec Institute of Technology"
chinzData.df[chinzData.df == "Electronic and Telecommunications Research Institute, South Korea"] <- "Electronics and Telecommunications Research Institute, South Korea"
chinzData.df[chinzData.df == "Freie Universitt Berlin"] <- "Free University Berlin"


#################################################
# Added information
# Citations / Year

currentYear <- 2015

chinzData.df$GS.citationsPerYear <- round((chinzData.df$GS.citations / ( currentYear - chinzData.df$Year) ) , digits=2)

chinzData.df$Scopus.citationsPerYear <- round((chinzData.df$Scopus.citations / ( currentYear - chinzData.df$Year) ) , digits=2)

chinzData.df$Scopus.NSCPerYear <- round((chinzData.df$Scopus.NSC / ( currentYear - chinzData.df$Year) ) , digits=2)

chinzData.df$ACM.citationsPerYear <- round((chinzData.df$ACM.citations / ( currentYear - chinzData.df$Year) ) , digits=2)

# Downloads/ year from ACM DL entry accession year
chinzData.df$Years.in.ACM.DL <- currentYear - chinzData.df$Year.in.ACM.DL
chinzData.df$ACM.downloads  <-  as.numeric(as.character(chinzData.df$ACM.downloads) )
chinzData.df$ACM.downloadsPerYear <- round((chinzData.df$ACM.downloads / chinzData.df$Years.in.ACM.DL ) , digits=2) 


################################################

theme_dmn <- function(base_size = 12, base_family = "Arial") {
  theme (
    axis.line =         element_blank(),
    axis.text.x =       element_text(size = base_size * 0.8 , lineheight = 0.9, colour = "black", vjust = 1),
    axis.text.y =       element_text(size = base_size * 0.8, lineheight = 0.9, colour = "black", hjust = 1),
    axis.ticks =        element_line(colour = "black"),
    axis.title.x =      element_text(size = base_size, vjust = 0.5),
    axis.title.y =      element_text(size = base_size, angle = 90, vjust = 0.5),
    axis.ticks.length = unit(0.15, "cm"),
    axis.ticks.margin = unit(0, "cm"),
    
    legend.background = element_rect(colour=NA), 
    legend.key =        element_rect(fill = NA, colour = "black", size = 0.25),
    legend.key.size =   unit(1.2, "lines"),
    legend.text =       element_text(size = base_size * 0.8),
    legend.title =      element_text(size = base_size * 0.8, face = "bold", hjust = 0),
    legend.position =   "right",
    
    panel.background =  element_rect(fill = NA, colour = "black", size = 0.25), 
    panel.border =      element_blank(),
    panel.grid.major =  element_blank(),
    panel.grid.minor =  element_blank(),
    panel.margin =      unit(0, "lines"),
    
    strip.background =  element_rect(fill = NA, colour = NA), 
    strip.text.x =      element_text(colour = "black", size = base_size * 0.8),
    strip.text.y =      element_text(colour = "black", size = base_size * 0.8, angle = -90),
    
    plot.background =   element_rect(colour = NA, fill = "white"),
    plot.title =        element_text(size = base_size * 1.2),
    plot.margin =       unit(c(1, 1, 0.5, 0.5), "lines")
  )
}


######################################################

#global counts

numOfItems <- nrow(chinzData.df)

chinzData.LongPapers.df <- chinzData.df[chinzData.df$Type == "paper", ]
numOfLongPapers <- nrow(chinzData.LongPapers.df)
  
chinzData.ShortPapers.df <- chinzData.df[chinzData.df$Type == "short", ]
numOfShortPapers <- nrow(chinzData.ShortPapers.df)

chinzData.Keynotes.df <- chinzData.df[chinzData.df$Type == "keynote", ]
numOfKeynotes <- nrow(chinzData.Keynotes.df)

chinzData.Posters.df <- chinzData.df[chinzData.df$Type == "poster", ]
numOfPosters <- nrow(chinzData.Posters.df)

chinzData.Demos.df <- chinzData.df[chinzData.df$Type == "demo", ]
numOfDemos <- nrow(chinzData.Demos.df)

chinzData.DocConsortiums.df <- chinzData.df[chinzData.df$Type == "doctoral consortium", ]
numOfDocConsortiums <- nrow(chinzData.DocConsortiums.df)

print(paste("Total number of items: ", numOfItems ) )
print(paste("Total number of long papers: ", numOfLongPapers ) )
print(paste("Total number of short papers: ", numOfShortPapers ) )
print(paste("Total number of posters: ", numOfPosters ) )
print(paste("Total number of demos: ", numOfDemos ) )
print(paste("Total number of doctoral consortiums: ", numOfDocConsortiums ) )
print(paste("Total number of keynotes: ", numOfKeynotes ) )

if ((numOfLongPapers + numOfShortPapers + numOfPosters + numOfDemos + numOfDocConsortiums + numOfKeynotes  ) == numOfItems) {
  print("Check on item types passed")
} else {
  print("Check on item types failed **************")
}


#type by year
table(chinzData.df$Type)
table(chinzData.df$Year)
table(chinzData.df[c("Year", "Type")])

#just ACM , i.e not 2004

APCHI.df <- chinzData.df[chinzData.df$Year == 2004  & !is.na(chinzData.df$Year), ]  # just APCHI
chinzDataACM.df <- chinzData.df[chinzData.df$Year != 2004  & !is.na(chinzData.df$Year), ] # exclude the APCHI proceedings

numAPCHIItems <- nrow(APCHI.df)
numACMItems <- nrow(chinzDataACM.df)

print(paste("Total number of APCHI items: ", numAPCHIItems ) )
print(paste("Total number of ACM papers: ", numACMItems ) )
print(paste("Total number of CHINZ items: ", numOfItems ) )

if ((numAPCHIItems + numACMItems) == numOfItems) {
  print("Check on ACM/APCHI item types passed")
} else {
  print("Check on ACM/APCHI item types failed **************")
}


# Full text exlcuding APCHI

chinzDataACMFullText.df <- chinzDataACM.df[chinzDataACM.df$ACM.DL.Fulltext == "1", ]
nrow(chinzDataACMFullText.df )

#Fulltext = ACM FullText + APCHI

chinzDataFullText.df <- chinzData.df[chinzData.df$Year == 2004 | chinzData.df$ACM.DL.Fulltext == "1", ]
numFullTextItems <- nrow(chinzDataFullText.df )
print(paste("Total number of fulltext items: ", numFullTextItems))


#Fulltext Phase 1 2001-2003

chinzDataFullTextPhase1.df <- chinzDataFullText.df[chinzDataFullText.df$Year == 2001 | chinzDataFullText.df$Year == 2002 | chinzDataFullText.df$Year == 2003, ]

nrow(chinzDataFullTextPhase1.df)

summary(chinzDataFullText.df$GS.citationsPerYear)

# APCHI

summary(APCHI.df$GS.citationsPerYear)

# Scopus indexed
chinzScopus.df <- chinzData.df[!is.na(chinzData.df$Scopus.citations),]

#####################################################

#Open Access

chinzOpen.df <- chinzData.df[chinzData.df$Open.Access & !is.na(chinzData.df$Open.Access), ]  # just Open Access
chinzClosed.df <- chinzData.df[!chinzData.df$Open.Access  & !is.na(chinzData.df$Open.Access), ] # just closed

numOpenItems <- nrow(chinzOpen.df)
numClosedItems <- nrow(chinzClosed.df)

print(paste("Total number of Open items: ", numOpenItems  ) )
print(paste("Total number of Closed items: ", numClosedItems ) )
print(paste("Total number of CHINZ items: ", numOfItems ) )

if ((numOpenItems + numClosedItems) == numOfItems) {
  print("Check on open item types passed")
} else {
  print("Check on open item types failed **************")
}

chinzOpenIR.df <- chinzData.df[chinzData.df$Open.Access & !is.na(chinzData.df$Open.Access) & chinzData.df$IR.URL != "", ] 
numOpenIRItems <- nrow(chinzOpenIR.df )
chinzOpenOther.df <- chinzData.df[chinzData.df$Open.Access & !is.na(chinzData.df$Open.Access) & chinzData.df$Non.IR.Open.URL != "", ] 
numOpenOtherItems <- nrow(chinzOpenOther.df )

print(paste("Total number of Open IR items: ", numOpenIRItems   ) )
print(paste("Total number of Open non-IR items: ", numOpenOtherItems  ) )

print("Open Access items by Year:")
table(chinzOpen.df$Year)


####################################################

#count number of authors

authorFields <- c("Author.1", "Author.2","Author.3", "Author.4", "Author.5", "Author.6", "Author.7", "Author.8")

chinzData.Authors.df <- chinzData.df[ ,authorFields] # 8 is max number of authors
chinzData.df$Num.AuthorsPerPaper <- rowSums(chinzData.Authors.df != "")
  
#summary(chinzData.df$Num.AuthorsPerPaper)

totalAuthorsPerYear <- aggregate(chinzData.df$Num.AuthorsPerPaper, by=list(year = chinzData.df$Year), sum)
meanAuthorsPerYear <- aggregate(chinzData.df$Num.AuthorsPerPaper, by=list(year = chinzData.df$Year), mean)
medianAuthorsPerYear <- aggregate(chinzData.df$Num.AuthorsPerPaper, by=list(year = chinzData.df$Year), median)

authors.df <- totalAuthorsPerYear
names(authors.df) [2] <- "totalAuthorsPerYear"
authors.df$meanAuthorsPerYear <- round(meanAuthorsPerYear$x, digits=1)
authors.df$medianAuthorsPerYear <- medianAuthorsPerYear$x
authors.df

#unique authors

justAuthors <- chinzData.df[, authorFields]

#a1 <- as.character(unlist(justAuthors[[1]] , use.names = FALSE))
#a2 <- as.character(unlist(justAuthors[[2]] , use.names = FALSE))
#a3 <- as.character(unlist(justAuthors[[3]] , use.names = FALSE))
#a4 <- as.character(unlist(justAuthors[[4]] , use.names = FALSE))
#a5 <- as.character(unlist(justAuthors[[5]] , use.names = FALSE))
#a6 <- as.character(unlist(justAuthors[[6]] , use.names = FALSE))
#a7 <- as.character(unlist(justAuthors[[7]] , use.names = FALSE))
#a8 <- as.character(unlist(justAuthors[[8]] , use.names = FALSE))

#authorList <- c(a1, a2, a3, a4, a5, a6, a7, a8)
#authorList <- authorList[authorList != ""]

x <- as.vector(as.character(unlist(justAuthors, use.names = FALSE)))
authorList <- x[x != ""]

print(paste("number of authors:", length(authorList)))
print(paste("number of unique authors:", length(unique(authorList))))

authorFreq.df <- as.data.frame(table(authorList))
sortedAuthorFreq.df <- authorFreq.df[order(-authorFreq.df$Freq), ]
top10AuthorFreq <- sortedAuthorFreq.df[1:10, ]
row.names(top10AuthorFreq) <- NULL 
print("Top 10 most frequent authors")
top10AuthorFreq

write.csv(sortedAuthorFreq.df, file = "authorsFreq.csv")

t1 <- table(chinzData.df[c("Year", "Num.AuthorsPerPaper")])
# table only for checking not for further calcs

#demo

demoAuthors <- chinzData.Demos.df[, authorFields]

x <- as.vector(as.character(unlist(demoAuthors, use.names = FALSE)))
demoAuthorsList <- x[x != ""]
print(paste("number of demo authors:", length(demoAuthorsList )))

#unqiues per year

uniqueAuthors <- function (chinzData.df, year, authorFields) {
  x <- chinzData.df[chinzData.df$Year == year, authorFields]
  x <- x[x != ""]
  result <- length(unique(x))
  return (result)
}

#uniqueAuthors(chinzData.df, 2001, authorFields)

print("Number of unique authors by year:")
sapply(2001:2012, function(x) {print(paste(x, uniqueAuthors(chinzData.df, x, authorFields) ) )} )
#y <- sapply(2001:2012, function(x) {c(x, uniqueAuthors(chinzData.df, x, authorFields) ) } )
#x <- sapply(2001:2012, function(x) {uniqueAuthors(chinzData.df, x, authorFields) } )

###################################################
# affiliations
#fractional? already fractional?

affiliationFields <- c("Affiliation.1", "Affiliation.2","Affiliation.3", "Affiliation.4", "Affiliation.5", "Affiliation.6", "Affiliation.7", "Affiliation.8")

chinzData.Affiliations.df <- chinzData.df[ ,affiliationFields] # 8 is max number of affiliations
chinzData.df$Num.AffiliationsPerPaper <- rowSums(chinzData.Affiliations.df != "")

numUniques <- function (nameList) {
  nameList <- nameList[nameList != ""]
  result <- length(unique(nameList))
  return (result)
}

chinzData.Affiliations.df$Num.UniqueAffiliationsPerPaper <- apply(chinzData.Affiliations.df,1,numUniques)

print("Number of unique affiliations:")
summary(chinzData.Affiliations.df$Num.UniqueAffiliationsPerPaper)
chinzData.df$Num.UniqueAffiliationsPerPaper <- chinzData.Affiliations.df$Num.UniqueAffiliationsPerPaper

table(chinzData.df[c("Year", "Num.UniqueAffiliationsPerPaper")])

meanUniqueAffiliationsPerYear <- aggregate(chinzData.df$Num.UniqueAffiliationsPerPaper, by=list(year = chinzData.df$Year), mean)
meanUniqueAffiliationsPerYear 


nonZeroAffiliations <- data.frame()
nonZeroAffiliations <- chinzData.df[chinzData.df$Num.AffiliationsPerPaper != 0, ] 

nonZeroAffiliations$numUniqueAffiliations <- nonZeroAffiliations[, length(unique(nonZeroAffiliations[affiliationFields])  ) ]


a1<- ggplot(nonZeroAffiliations, aes(x= nonZeroAffiliations$Num.AffiliationsPerPaper))
a1 + geom_bar(stat="bin")


totalAffiliationsPerYear <- aggregate(chinzData.df$Num.AffiliationsPerPaper, by=list(year = chinzData.df$Year), sum)
totalAffiliationsPerYear
meanAffiliationsPerYear <- aggregate(chinzData.df$Num.AffiliationsPerPaper, by=list(year = chinzData.df$Year), mean)
meanAffiliationsPerYear
medianAffiliationsPerYear <- aggregate(chinzData.df$Num.AffiliationsPerPaper, list(year = chinzData.df$Year), median)
medianAffiliationsPerYear

#unique authors

justAffiliations <- chinzData.df[, affiliationFields]

x <- as.vector(as.character(unlist(justAffiliations, use.names = FALSE)))
affiliationList <- x[x != ""]

print(paste("number of affiliations:", length(affiliationList)))
print(paste("number of unique affiliations:", length(unique(affiliationList))))

affiliationFreq.df <- as.data.frame(table(affiliationList))
sortedAffiliationFreq.df <- affiliationFreq.df[order(-affiliationFreq.df$Freq), ]
topAffiliationFreq <- sortedAffiliationFreq.df [1:20, ]
row.names(topAffiliationFreq ) <- NULL 
print("Top 20 most frequent affiliations")
top10AuthorFreq
topAffiliationFreq

write.csv(sortedAffiliationFreq.df, file = "affiliationFreq.csv")

t1 <- table(chinzData.df[c("Year", "Num.AffiliationsPerPaper")])

#############################

#citations / year


apchipapersOnly.df <- APCHI.df[APCHI.df$Type != "doctoral consortium", ]
apchiPapersOnlyGSCitationsPerYear <- apchipapersOnly.df$GS.citationsPerYear
summary(apchiPapersOnlyGSCitationsPerYear)


apchiGSCitationsPerYear <- APCHI.df$GS.citationsPerYear
summary(apchiGSCitationsPerYear)

chinz2005.df <- chinzData.df[chinzData.df$Year == 2005, ]
chinz2005CitationsPerYear <- chinz2005.df$GS.citationsPerYear
summary(chinz2005CitationsPerYear)
chinz2006.df <- chinzData.df[chinzData.df$Year == 2006, ]
chinz2006CitationsPerYear <- chinz2006.df$GS.citationsPerYear
summary(chinz2006CitationsPerYear)
chinz2007.df <- chinzData.df[chinzData.df$Year == 2007, ]
chinz2007CitationsPerYear <- chinz2007.df$GS.citationsPerYear
summary(chinz2007CitationsPerYear)
chinz2008.df <- chinzData.df[chinzData.df$Year == 2008, ]
chinz2008CitationsPerYear <- chinz2008.df$GS.citationsPerYear
summary(chinz2008CitationsPerYear)

##############################

#Create Open and Closed subsets based on Open Access status

chinzData.Open.df <- chinzData.df[chinzData.df$Open.Access == 1, ]

chinzData.Closed.df <- chinzData.df[chinzData.df$Open.Access == 0, ]

numOpenPapers <- nrow(chinzData.Open.df)
numClosedPapers <- nrow(chinzData.Closed.df)
totalPapers <- numOpenPapers + numClosedPapers
print(paste("Open papers: ", numOpenPapers) )
print(paste("Closed papers: ", numClosedPapers) )
print(paste("Total papers: ", totalPapers) )
ifelse(nrow(chinzData.df) == totalPapers, print("Check on open/closedness passed"), print("Check on open/closedness failed ****************"))


irItems <- chinzData.Open.df[chinzData.df$IR.URL != "",]
webItems <- chinzData.Open.df[chinzData.df$Non.IR.Open.URL != "",]

table(chinzData.Open.df$Year)


apchiOpen.df <- APCHI.df[APCHI.df$Open.Access == 1, ]
apchiOpenRate <- nrow(apchiOpen.df) / nrow(APCHI.df)
apchiOpenRate

x <- chinzData.Open.df$GS.citations
summary(x)

y <- chinzData.Closed.df$GS.citations
summary(y)

z <- chinzData.df$GS.citations
summary(z)


x <- chinzData.Open.df$Scopus.citations
summary(x)

y <- chinzData.Closed.df$Scopus.citations
summary(y)

z <- chinzData.df$Scopus.citations
summary(z)

x <- chinzData.Open.df$Scopus.NSC
summary(x)

y <- chinzData.Closed.df$Scopus.NSC
summary(y)

z <- chinzData.df$Scopus.NSC
summary(z)

x <- chinzData.Open.df$ACM.citations
summary(x)

y <- chinzData.Closed.df$ACM.citations
summary(y)

z <- chinzData.df$ACM.citations
summary(z)


########################

#self-citations across those items indexed in Scopus
nrow(chinzScopus.df)
totalScopusCitations <- sum(as.vector(chinzScopus.df$Scopus.citations), na.rm = TRUE)
totalScopusNSC <- sum(as.vector(chinzScopus.df$Scopus.NSC), na.rm = TRUE)
scopusSelfCitationRate <- round( 1 - (totalScopusNSC / totalScopusCitations), digits=2 )
print(paste("Total citations (Scopus):", totalScopusCitations ))
print(paste("Total citations (Scopus NSC):", totalScopusNSC ))
print(paste("Self citation rate (Scopus):", scopusSelfCitationRate ))

totalACMCitations <-  sum(as.vector(chinzData.df$ACM.citations), na.rm = TRUE)
print(paste("Total citations (ACM):", totalACMCitations ))
totalGSCitations <-  sum(as.vector(chinzData.df$GS.citations), na.rm = TRUE)
print(paste("Total citations (GS):", totalGSCitations ))

###############################################
#citations - only for fulltextitems

chinzDataFullTextPapers.df <- chinzDataACMFullText.df[chinzDataACMFullText.df$Type == "paper" |
                                                      chinzDataACMFullText.df$Type == "short" | 
                                                      chinzDataACMFullText.df$Type == "poster", ]

gsCitations <- chinzDataFullTextPapers.df["GS.citations"]
scopusCitations <- chinzDataFullTextPapers.df["Scopus.citations"]
scopusNSCCitations <- chinzDataFullTextPapers.df["Scopus.NSC"]
ACMCitations <- chinzDataFullTextPapers.df["ACM.citations"]
numFullText <- nrow(chinzDataFullTextPapers.df)
print(paste("Number of papers, shorts and posters (excluding APCHI):", numFullText ))

summary(gsCitations)
t.df <- as.data.frame(table(gsCitations))
numUncitedGS <- t.df[t.df$gsCitations == 0, ]$Freq
propUncitedGS <- round(numUncitedGS / numFullText, digits=2)
print(paste("Number of uncited full-text items via GS: ",  numUncitedGS ))
print(paste("Proportion of uncited full-text items via GS: ",  propUncitedGS  ))
boxplot(gsCitations)

summary(scopusCitations)
t.df <- as.data.frame(table(scopusCitations))
numUncitedScopus <- t.df[t.df$scopusCitations == 0, ]$Freq
propUncitedScopus <- round(numUncitedScopus / numFullText, digits=2)
print(paste("Number of uncited full-text items via Scopus: ",  numUncitedScopus ))
print(paste("Proportion of uncited full-text items via Scopus: ",  propUncitedScopus  ))
boxplot(scopusCitations)

summary(scopusNSCCitations)
t.df <- as.data.frame(table(scopusNSCCitations))
numUncitedScopusNSC <- t.df[t.df$scopusNSCCitations == 0, ]$Freq
propUncitedScopusNSC <- round(numUncitedScopusNSC / numFullText, digits=2)
print(paste("Number of uncited full-text items via Scopus (No self-citations): ",  numUncitedScopusNSC ))
print(paste("Proportion of uncited full-text items via Scopus  (No self-citations): ",  propUncitedScopusNSC  ))
boxplot(scopusNSCCitations)

summary(ACMCitations)
t.df <- as.data.frame(table(ACMCitations))
numUncitedACMCitations <- t.df[t.df$ACMCitations == 0, ]$Freq
propUncitedACMCitations <- round(numUncitedACMCitations / numFullText, digits=2)
print(paste("Number of uncited full-text items via ACM: ",  numUncitedACMCitations ))
print(paste("Proportion of uncited full-text items via ACM: ",  propUncitedACMCitations  ))
boxplot(ACMCitations)

#APCHI

APCHIpapers.df <- APCHI.df[APCHI.df$Type != "doctoral consortium", ]
APCHIpapers.df <- APCHI.df
gsAPCHICitations <- APCHIpapers.df["GS.citations"]
scopusAPCHICitations <- APCHIpapers.df["Scopus.citations"]
scopusNSCAPCHICitations <- APCHIpapers.df["Scopus.NSC"]
numFullTextAPCHI <- nrow(gsAPCHICitations)
print(paste("Number of APCHI items: ", numFullTextAPCHI))

summary(gsAPCHICitations)
t.df <- as.data.frame(table(gsAPCHICitations))
numUncitedAPCHIGS <- t.df[t.df$gsAPCHICitations == 0, ]$Freq
propUncitedAPCHIGS <- round(numUncitedAPCHIGS / numFullTextAPCHI, digits=2)
print(paste("Number of uncited full-text APCHI items via GS: ",  numUncitedAPCHIGS ))
print(paste("Proportion of uncited full-text APCHI items via GS: ",  propUncitedAPCHIGS  ))
boxplot(gsAPCHICitations)

summary(scopusAPCHICitations)
t.df <- as.data.frame(table(scopusAPCHICitations))
numUncitedAPCHIScopus <- t.df[t.df$scopusAPCHICitations == 0, ]$Freq
propUncitedAPCHIScopus <- round(numUncitedAPCHIScopus / numFullTextAPCHI, digits=2)
print(paste("Number of uncited full-text APCHI items via Scopus: ",  numUncitedAPCHIScopus ))
print(paste("Proportion of uncited full-text APCHI items via Scopus: ",  propUncitedAPCHIScopus  ))
boxplot(scopusAPCHICitations)

summary(scopusNSCAPCHICitations)
t.df <- as.data.frame(table(scopusNSCAPCHICitations))
numUncitedAPCHIScopusNSC <- t.df[t.df$scopusNSCAPCHICitations == 0, ]$Freq
propUncitedAPCHIScopusNSC <- round(numUncitedAPCHIScopusNSC / numFullTextAPCHI, digits=2)
print(paste("Number of uncited full-text APCHI items via Scopus (excl. self-citations): ",  numUncitedAPCHIScopusNSC ))
print(paste("Proportion of uncited full-text APCHI items via Scopus(excl. self-citations): ",  propUncitedAPCHIScopusNSC))
boxplot(scopusNSCAPCHICitations)

###############################################
      
b1 <- ggplot(chinzData.df, aes(x= GS.citations))
b1 + geom_bar(binwidth=1) +  labs( x = "Google Scholar citations", y = "Count")

b2 <- ggplot(chinzData.df, aes(x= Scopus.citations))
b2 + geom_bar(binwidth=1)

b3 <- ggplot(chinzData.df, aes(x= ACM.citations)) 
b3 + geom_bar(binwidth=1)
        
   
cor(chinzDataACMFullText.df$GS.citations,  chinzDataACMFullText.df$ACM.citations, use="complete", method = "pearson")
cor(chinzDataACMFullText.df$Scopus.citations,  chinzDataACMFullText.df$ACM.citations, use="complete", method = "pearson")
cor(chinzScopus.df$Scopus.citations,  chinzScopus.df$Scopus.NSC, use="complete", method = "pearson")
cor(chinzScopus.df$GS.citations, chinzScopus.df$Scopus.citations, use="complete", method = "pearson")


scatter <- ggplot(data = chinzScopus.df, aes(x=Scopus.citations, y=GS.citations))
scatter + geom_point(shape=4, size=3, alpha=0.4, position=position_jitter(width=.2,height=.2))  + theme_dmn() + 
# geom_smooth(method=lm) + #theme_dmn() + 
#  scale_x_continuous(expand = c(0, 0)) + scale_y_continuous(expand = c(0, 0)) +
  geom_abline(intercept = 0, slope = 1, alpha=0.5, color="black", linetype=3) +
  labs( y = "Google Scholar citations", x = "Scopus citations")
#title = "Citations to CHINZ papers: 2001-2012 (with added jitter)"

y1 <- lm (GS.citationsPerYear ~ Scopus.citationsPerYear, chinzData.df)
summary(y1)

scatter <- ggplot(data = chinzData.df, aes(x=GS.citationsPerYear, y=Scopus.citationsPerYear, xmin=0))
scatter + geom_point(size=3)  + geom_smooth(method=lm) + theme_dmn() + 
  #  scale_x_continuous(expand = c(0, 0)) + scale_y_continuous(expand = c(0, 0)) +
  labs( x = "Google Scholar citations/Year", y = "Scopus citations/Year", title = "CHINZ citations/Year: 2001-2012")


# ordering for ranked lists

sortedGSCitations.df <- chinzData.df[order(-chinzData.df$GS.citations),] 
top10GSCitations <- sortedGSCitations.df[1:10, ]
outputTop10GSCitations <- top10GSCitations[ , c("Year","Type", "DOI.URL", "Title", "GS.citations")]

sortedGSCitationsPerYear.df <- chinzData.df[order(-chinzData.df$GS.citationsPerYear),] 
top10GSCitationsPerYear <- sortedGSCitationsPerYear.df[1:10, ]
outputTop10GSCitationsPerYear <- top10GSCitationsPerYear[ , c("Year","Type", "DOI.URL", "Title", "GS.citationsPerYear")]

sortedScopusCitations.df <- chinzData.df[order(-chinzData.df$Scopus.citations),] 
top10ScopusCitations <- sortedScopusCitations.df[1:10, ]
outputTop10ScopusCitations <- top10ScopusCitations[ , c("Year","Type", "DOI.URL", "Title", "Scopus.citations")]

sortedScopusCitationsPerYear.df <- chinzData.df[order(-chinzData.df$Scopus.citationsPerYear),] 
top10ScopusCitationsPerYear <- sortedScopusCitationsPerYear.df [1:10, ]
outputTop10ScopusCitationsPerYear <- top10ScopusCitationsPerYear[ , c("Year","Type", "DOI.URL", "Title", "Scopus.citationsPerYear")]


sortedScopusNSC.df <- chinzData.df[order(-chinzData.df$Scopus.NSC),] 
top10ScopusNSC <- sortedScopusNSC.df [1:10, ]
outputTop10ScopusNSC <- top10ScopusNSC[ , c("Year","Type", "DOI.URL", "Title", "Scopus.NSC")]

sortedScopusNSCPerYear.df <- chinzData.df[order(-chinzData.df$Scopus.NSCPerYear),] 
top10ScopusNSCPerYear <- sortedScopusNSCPerYear.df [1:10, ]
outputTop10ScopusNSCPerYear <- top10ScopusNSCPerYear[ , c("Year","Type", "DOI.URL", "Title", "Scopus.NSCPerYear")]


#CHINZ on its own

sortedChinzDataACMGSCitations.df <- chinzDataACM.df[order(-chinzDataACM.df$GS.citations),] 
sortedChinzDataACMScopus.df <- chinzDataACM.df[order(-chinzDataACM.df$Scopus.citations),] 
sortedChinzDataACMScopusNSC.df <- chinzDataACM.df[order(-chinzDataACM.df$Scopus.NSC),] 


sortedChinzDataACMACMCitations.df <- chinzDataACM.df[order(-chinzDataACM.df$ACM.citations),] 


# h indices

library(CITAN)
print("GS H-Index of CHINZ (inc APCHI)")
index_h(sortedGSCitations.df$GS.citations[1:50])
print("Scopus H-Index of CHINZ (inc APCHI)")
index_h(sortedScopusCitations.df$Scopus.citations[1:50])
print("Scopus H-Index (Excluding self-citations)of CHINZ (inc APCHI)")
index_h(sortedScopusNSC.df$Scopus.NSC[1:50])

print("GS H-Index of CHINZ (excl APCHI)")
index_h(sortedChinzDataACMGSCitations.df$GS.citations[1:50])
print("Scopus H-Index of CHINZ (excl APCHI)")
index_h(sortedChinzDataACMScopus.df$Scopus.citations[1:50])
print("Scopus H-Index (Excluding self-citations)of CHINZ (excl APCHI)")
index_h(sortedChinzDataACMScopusNSC.df$Scopus.NSC[1:50])
print("ACM H-Index of CHINZ (excl APCHI)")
index_h(sortedChinzDataACMACMCitations.df$ACM.citations[1:50])





